@@ -24,6 +24,7 @@
     - Return Metablock containing a Link object which can be can be signed
       and stored to disk
 """
+import six
 import glob
 import logging
 import os
@@ -212,8 +213,8 @@ def record_artifacts_as_dict(artifacts, exclude_patterns=None,
       os.chdir(base_path)
 
     except Exception as e:
-      raise ValueError("Could not use '{}' as base path: '{}'".format(
-          base_path, e))
+      six.raise_from(ValueError("Could not use '{}' as base path: '{}'".format(
+          base_path, e)), e)
 
   # Normalize passed paths
   norm_artifacts = []
@@ -357,10 +358,12 @@ def execute_link(link_cmd_args, record_streams):
   """
   if record_streams:
     return_code, stdout_str, stderr_str = \
-        securesystemslib.process.run_duplicate_streams(link_cmd_args)
+        securesystemslib.process.run_duplicate_streams(link_cmd_args,
+            timeout=float(in_toto.settings.LINK_CMD_EXEC_TIMEOUT))
 
   else:
     process = securesystemslib.process.run(link_cmd_args, check=False,
+      timeout=float(in_toto.settings.LINK_CMD_EXEC_TIMEOUT),
       stdout=securesystemslib.process.DEVNULL,
       stderr=securesystemslib.process.DEVNULL)
     stdout_str = stderr_str = ""
@@ -464,7 +467,7 @@ def in_toto_run(name, material_list, product_list, link_cmd_args,
         default gpg home directory is used.
 
     exclude_patterns (optional): A list of filename patterns to exclude certain
-        files from being recorded as artifacts.
+        files from being recorded as artifacts. See Config docs for details.
 
     base_path (optional): A path relative to which artifacts are recorded.
         Default is the current working directory.
@@ -631,7 +634,7 @@ def in_toto_record_start(step_name, material_list, signing_key=None,
         default gpg home directory is used.
 
     exclude_patterns (optional): A list of filename patterns to exclude certain
-        files from being recorded as artifacts.
+        files from being recorded as artifacts. See Config docs for details.
 
     base_path (optional): A path relative to which artifacts are recorded.
         Default is the current working directory.
